@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -34,7 +34,7 @@ import org.junit.jupiter.api.Test;
  *
  * @see "http://www.cuj.com/documents/s=8038/cuj0006philips/"
  */
-public class DoubleMetaphoneTest extends AbstractStringEncoderTest<DoubleMetaphone> {
+class DoubleMetaphoneTest extends AbstractStringEncoderTest<DoubleMetaphone> {
 
     /**
      * Test data from https://aspell.net/test/orig/batch0.tab.
@@ -1008,21 +1008,21 @@ public class DoubleMetaphoneTest extends AbstractStringEncoderTest<DoubleMetapho
      * Tests encoding APIs in one place.
      */
     private void assertDoubleMetaphone(final String expected, final String source) {
-        assertEquals(expected, this.getStringEncoder().encode(source));
+        assertEquals(expected, getStringEncoder().encode(source));
         try {
-            assertEquals(expected, this.getStringEncoder().encode((Object) source));
+            assertEquals(expected, getStringEncoder().encode((Object) source));
         } catch (final EncoderException e) {
             fail("Unexpected exception: " + e);
         }
-        assertEquals(expected, this.getStringEncoder().doubleMetaphone(source));
-        assertEquals(expected, this.getStringEncoder().doubleMetaphone(source, false));
+        assertEquals(expected, getStringEncoder().doubleMetaphone(source));
+        assertEquals(expected, getStringEncoder().doubleMetaphone(source, false));
     }
 
     /**
      * Tests encoding APIs in one place.
      */
     public void assertDoubleMetaphoneAlt(final String expected, final String source) {
-        assertEquals(expected, this.getStringEncoder().doubleMetaphone(source, true));
+        assertEquals(expected, getStringEncoder().doubleMetaphone(source, true));
     }
 
     @Override
@@ -1031,37 +1031,37 @@ public class DoubleMetaphoneTest extends AbstractStringEncoderTest<DoubleMetapho
     }
 
     public void doubleMetaphoneEqualTest(final String[][] pairs, final boolean useAlternate) {
-        this.validateFixture(pairs);
+        validateFixture(pairs);
         for (final String[] pair : pairs) {
             final String name0 = pair[0];
             final String name1 = pair[1];
             final String failMsg = "Expected match between " + name0 + " and " + name1 + " (use alternate: " + useAlternate + ")";
-            assertTrue(this.getStringEncoder().isDoubleMetaphoneEqual(name0, name1, useAlternate), failMsg);
-            assertTrue(this.getStringEncoder().isDoubleMetaphoneEqual(name1, name0, useAlternate), failMsg);
+            assertTrue(getStringEncoder().isDoubleMetaphoneEqual(name0, name1, useAlternate), failMsg);
+            assertTrue(getStringEncoder().isDoubleMetaphoneEqual(name1, name0, useAlternate), failMsg);
             if (!useAlternate) {
-                assertTrue(this.getStringEncoder().isDoubleMetaphoneEqual(name0, name1), failMsg);
-                assertTrue(this.getStringEncoder().isDoubleMetaphoneEqual(name1, name0), failMsg);
+                assertTrue(getStringEncoder().isDoubleMetaphoneEqual(name0, name1), failMsg);
+                assertTrue(getStringEncoder().isDoubleMetaphoneEqual(name1, name0), failMsg);
             }
         }
     }
 
     public void doubleMetaphoneNotEqualTest(final boolean alternate) {
-        assertFalse(this.getStringEncoder().isDoubleMetaphoneEqual("Brain", "Band", alternate));
-        assertFalse(this.getStringEncoder().isDoubleMetaphoneEqual("Band", "Brain", alternate));
+        assertFalse(getStringEncoder().isDoubleMetaphoneEqual("Brain", "Band", alternate));
+        assertFalse(getStringEncoder().isDoubleMetaphoneEqual("Band", "Brain", alternate));
 
         if (!alternate) {
-            assertFalse(this.getStringEncoder().isDoubleMetaphoneEqual("Brain", "Band"));
-            assertFalse(this.getStringEncoder().isDoubleMetaphoneEqual("Band", "Brain"));
+            assertFalse(getStringEncoder().isDoubleMetaphoneEqual("Brain", "Band"));
+            assertFalse(getStringEncoder().isDoubleMetaphoneEqual("Band", "Brain"));
         }
     }
 
     @Test
-    public void testCCedilla() {
-        assertTrue(this.getStringEncoder().isDoubleMetaphoneEqual("\u00e7", "S")); // c-cedilla
+    void testCCedilla() {
+        assertTrue(getStringEncoder().isDoubleMetaphoneEqual("\u00e7", "S")); // c-cedilla
     }
 
     @Test
-    public void testCodec184() {
+    void testCodec184() {
         assertTrue(new DoubleMetaphone().isDoubleMetaphoneEqual("", "", false));
         assertTrue(new DoubleMetaphone().isDoubleMetaphoneEqual("", "", true));
         assertFalse(new DoubleMetaphone().isDoubleMetaphoneEqual("aa", "", false));
@@ -1071,12 +1071,12 @@ public class DoubleMetaphoneTest extends AbstractStringEncoderTest<DoubleMetapho
     }
 
     @Test
-    public void testCodec320() {
+    void testCodec320() {
         assertTrue(new DoubleMetaphone().isDoubleMetaphoneEqual("ANGHELINA", "ANKL", false));
     }
 
     @Test
-    public void testDoubleMetaphone() {
+    void testDoubleMetaphone() {
         assertDoubleMetaphone("TSTN", "testing");
         assertDoubleMetaphone("0", "The");
         assertDoubleMetaphone("KK", "quick");
@@ -1117,15 +1117,15 @@ public class DoubleMetaphoneTest extends AbstractStringEncoderTest<DoubleMetapho
     }
 
     @Test
-    public void testEmpty() {
-        assertNull(this.getStringEncoder().doubleMetaphone(null));
-        assertNull(this.getStringEncoder().doubleMetaphone(""));
-        assertNull(this.getStringEncoder().doubleMetaphone(" "));
-        assertNull(this.getStringEncoder().doubleMetaphone("\t\n\r "));
+    void testEmpty() {
+        assertNull(getStringEncoder().doubleMetaphone(null));
+        assertNull(getStringEncoder().doubleMetaphone(""));
+        assertNull(getStringEncoder().doubleMetaphone(" "));
+        assertNull(getStringEncoder().doubleMetaphone("\t\n\r "));
     }
 
     @Test
-    public void testIsDoubleMetaphoneEqualBasic() {
+    void testIsDoubleMetaphoneEqualBasic() {
         final String[][] testFixture = { {
                 "", "" }, {
                 "Case", "case" }, {
@@ -1146,7 +1146,7 @@ public class DoubleMetaphoneTest extends AbstractStringEncoderTest<DoubleMetapho
      * Example in the original article but failures in this Java impl:
      */
     @Test
-    public void testIsDoubleMetaphoneEqualExtended1() {
+    void testIsDoubleMetaphoneEqualExtended1() {
         //        String[][] testFixture = new String[][] { { "Smith", "Schmidt" }
         //        };
         //        doubleMetaphoneEqualTest(testFixture, false);
@@ -1154,7 +1154,7 @@ public class DoubleMetaphoneTest extends AbstractStringEncoderTest<DoubleMetapho
     }
 
     @Test
-    public void testIsDoubleMetaphoneEqualExtended2() {
+    void testIsDoubleMetaphoneEqualExtended2() {
         final String[][] testFixture = { { "Jablonski", "Yablonsky" }
         };
         //doubleMetaphoneEqualTest(testFixture, false);
@@ -1166,8 +1166,8 @@ public class DoubleMetaphoneTest extends AbstractStringEncoderTest<DoubleMetapho
      * FIXTURE array.
      */
     @Test
-    public void testIsDoubleMetaphoneEqualExtended3() {
-        this.validateFixture(FIXTURE);
+    void testIsDoubleMetaphoneEqualExtended3() {
+        validateFixture(FIXTURE);
         final StringBuilder failures = new StringBuilder();
         final StringBuilder matches = new StringBuilder();
         final String cr = System.lineSeparator();
@@ -1176,8 +1176,8 @@ public class DoubleMetaphoneTest extends AbstractStringEncoderTest<DoubleMetapho
         for (int i = 0; i < FIXTURE.length; i++) {
             final String name0 = FIXTURE[i][0];
             final String name1 = FIXTURE[i][1];
-            final boolean match1 = this.getStringEncoder().isDoubleMetaphoneEqual(name0, name1, false);
-            final boolean match2 = this.getStringEncoder().isDoubleMetaphoneEqual(name0, name1, true);
+            final boolean match1 = getStringEncoder().isDoubleMetaphoneEqual(name0, name1, false);
+            final boolean match2 = getStringEncoder().isDoubleMetaphoneEqual(name0, name1, true);
             if (!match1 && !match2) {
                 final String failMsg = "[" + i + "] " + name0 + " and " + name1 + cr;
                 failures.append(failMsg);
@@ -1198,13 +1198,13 @@ public class DoubleMetaphoneTest extends AbstractStringEncoderTest<DoubleMetapho
     }
 
     @Test
-    public void testIsDoubleMetaphoneEqualWithMATCHES() {
-        this.validateFixture(MATCHES);
+    void testIsDoubleMetaphoneEqualWithMATCHES() {
+        validateFixture(MATCHES);
         for (int i = 0; i < MATCHES.length; i++) {
             final String name0 = MATCHES[i][0];
             final String name1 = MATCHES[i][1];
-            final boolean match1 = this.getStringEncoder().isDoubleMetaphoneEqual(name0, name1, false);
-            final boolean match2 = this.getStringEncoder().isDoubleMetaphoneEqual(name0, name1, true);
+            final boolean match1 = getStringEncoder().isDoubleMetaphoneEqual(name0, name1, false);
+            final boolean match2 = getStringEncoder().isDoubleMetaphoneEqual(name0, name1, true);
             if (!match1 && !match2) {
                 fail("Expected match [" + i + "] " + name0 + " and " + name1);
             }
@@ -1212,21 +1212,21 @@ public class DoubleMetaphoneTest extends AbstractStringEncoderTest<DoubleMetapho
     }
 
     @Test
-    public void testIsDoubleMetaphoneNotEqual() {
+    void testIsDoubleMetaphoneNotEqual() {
         doubleMetaphoneNotEqualTest(false);
         doubleMetaphoneNotEqualTest(true);
     }
 
     @Test
-    public void testNTilde() {
-        assertTrue(this.getStringEncoder().isDoubleMetaphoneEqual("\u00f1", "N")); // n-tilde
+    void testNTilde() {
+        assertTrue(getStringEncoder().isDoubleMetaphoneEqual("\u00f1", "N")); // n-tilde
     }
 
     /**
      * Test setting maximum length
      */
     @Test
-    public void testSetMaxCodeLength() {
+    void testSetMaxCodeLength() {
         final String value = "jumped";
 
         final DoubleMetaphone doubleMetaphone = new DoubleMetaphone();
